Unix: [![Unix Build Status](https://img.shields.io/travis/jacebrowning/euchre/develop.svg)](https://travis-ci.org/jacebrowning/euchre) Windows: [![Windows Build Status](https://img.shields.io/appveyor/ci/jacebrowning/euchre/develop.svg)](https://ci.appveyor.com/project/jacebrowning/euchre)<br>Metrics: [![Coverage Status](https://img.shields.io/coveralls/jacebrowning/euchre/develop.svg)](https://coveralls.io/r/jacebrowning/euchre) [![Scrutinizer Code Quality](https://img.shields.io/scrutinizer/g/jacebrowning/euchre.svg)](https://scrutinizer-ci.com/g/jacebrowning/euchre/?branch=develop)<br>Usage: [![PyPI Version](https://img.shields.io/pypi/v/Euchre.svg)](https://pypi.org/project/Euchre) [![PyPI License](https://img.shields.io/pypi/l/Euchre.svg)](https://pypi.org/project/Euchre)

# Overview

Sample project generated from jacebrowning/template-python.

This project was generated with [cookiecutter](https://github.com/audreyr/cookiecutter) using [jacebrowning/template-python](https://github.com/jacebrowning/template-python).

# Setup

## Requirements

* Python 3.7+

## Installation

Install Euchre with pip:

```sh
$ pip install Euchre
```

or directly from the source code:

```sh
$ git clone https://github.com/jacebrowning/euchre.git
$ cd euchre
$ python setup.py install
```

# Usage

After installation, the package can imported:

```sh
$ python
>>> import euchre
>>> euchre.__version__
```
